summaryrefslogtreecommitdiff
path: root/source/slang/slang-ir-deduplicate.cpp
diff options
context:
space:
mode:
authorYong He <yonghe@outlook.com>2020-08-14 12:56:43 -0700
committerGitHub <noreply@github.com>2020-08-14 12:56:43 -0700
commit0640a10ab85f8be3c3c925cb70711560265e6548 (patch)
treed1ec2068c5ffe6845eabcd425504014ab0bed1a0 /source/slang/slang-ir-deduplicate.cpp
parentb37a7770d9781515f70047665d12680a5838406d (diff)
Fix tuple type lowering (#1499)
Co-authored-by: Tim Foley <tfoleyNV@users.noreply.github.com>
Diffstat (limited to 'source/slang/slang-ir-deduplicate.cpp')
-rw-r--r--source/slang/slang-ir-deduplicate.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/source/slang/slang-ir-deduplicate.cpp b/source/slang/slang-ir-deduplicate.cpp
index 81bb2371e..83090e5ff 100644
--- a/source/slang/slang-ir-deduplicate.cpp
+++ b/source/slang/slang-ir-deduplicate.cpp
@@ -24,10 +24,11 @@ namespace Slang
}
IRInst* addTypeValue(IRInst* value)
{
// Do not deduplicate struct types.
switch (value->op)
{
case kIROp_StructType:
+ case kIROp_InterfaceType:
return value;
default:
break;
@@ -24,10 +24,11 @@ namespace Slang
IRInst* addTypeValue(IRInst* value)
{
- // Do not deduplicate struct types.
+ // Do not deduplicate struct or interface types.
switch (value->op)
{